pub struct Column<'a, Message, Theme = Theme, Renderer = Renderer> { /* private fields */ }applet only.Expand description
A container that distributes its contents vertically.
Example
use iced::widget::{button, column};
#[derive(Debug, Clone)]
enum Message {
// ...
}
fn view(state: &State) -> Element<'_, Message> {
column![
"I am on top!",
button("I am in the center!"),
"I am below.",
].into()
}Implementations
Sourceimpl<'a, Message, Theme, Renderer> Column<'a, Message, Theme, Renderer>where
Renderer: Renderer,
impl<'a, Message, Theme, Renderer> Column<'a, Message, Theme, Renderer>where
Renderer: Renderer,
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a Column with the given capacity.
Sourcepub fn with_children(
children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn with_children( children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self
Creates a Column with the given elements.
Sourcepub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self
pub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self
Creates a Column from an already allocated Vec.
Keep in mind that the Column will not inspect the Vec, which means
it won’t automatically adapt to the sizing strategy of its contents.
If any of the children have a Length::Fill strategy, you will need to
call Column::width or Column::height accordingly.
Sourcepub fn spacing(self, amount: impl Into<Pixels>) -> Self
pub fn spacing(self, amount: impl Into<Pixels>) -> Self
Sets the vertical spacing between elements.
Custom margins per element do not exist in iced. You should use this method instead! While less flexible, it helps you keep spacing between elements consistent.
Sourcepub fn max_width(self, max_width: impl Into<Pixels>) -> Self
pub fn max_width(self, max_width: impl Into<Pixels>) -> Self
Sets the maximum width of the Column.
Sourcepub fn align_x(self, align: impl Into<Horizontal>) -> Self
pub fn align_x(self, align: impl Into<Horizontal>) -> Self
Sets the horizontal alignment of the contents of the Column .
Sourcepub fn clip(self, clip: bool) -> Self
pub fn clip(self, clip: bool) -> Self
Sets whether the contents of the Column should be clipped on
overflow.
Sourcepub fn push(
self,
child: impl Into<Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn push( self, child: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Self
Adds an element to the Column.
Sourcepub fn push_maybe(
self,
child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>,
) -> Self
pub fn push_maybe( self, child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>, ) -> Self
Adds an element to the Column, if Some.
Sourcepub fn extend(
self,
children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>,
) -> Self
pub fn extend( self, children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self
Extends the Column with the given children.